| addVariableSet | R Documentation |
Allows to store predefined set of variable names in the object that
can be easily accessed via getVariableSet().
addVariableSet(object, variable_names, set_name, overwrite = FALSE)
object |
A valid cypro object. |
variable_names |
Character vector. Denotes the variable names that are part of the variable set. |
set_name |
Character value. The name of the set of variable names. |
overwrite |
Logical value. Must be set to TRUE in case of overlapping variable names. (Note that overwriting stat variables leads to all analysis progress of affected variable sets being discarded.) |
An updated version of the input cypro-object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.