check_object: Check object input

View source: R/check-family.R

check_objectR Documentation

Check object input

Description

Makes sure that object input is of class cypro and that it contains the relevant information needed for the function.

Usage

check_object(
  object,
  experiment = NULL,
  set_up_req = "process_data",
  exp_type_req = NULL,
  module_req = NULL
)

Arguments

object

A valid cypro object.


theMILOlab/cypro documentation built on April 5, 2022, 2:03 a.m.