compute_migration_efficiency: Calculate migration efficiency

View source: R/compute-family.R

compute_migration_efficiencyR Documentation

Calculate migration efficiency

Description

Calculate migration efficiency

Usage

compute_migration_efficiency(x_coords, y_coords, total_dist)

Arguments

x_coords

Numeric vector. Refers to x-coordinates of object.

y_coords

Numeric vector. Refers to y-coordinates of object.

total_dist

Numeric vector/value. Refers to the total distance the object of interested has traveled.

Value

A numeric value assessing how efficient the object of interested has migrated.


theMILOlab/cypro documentation built on April 5, 2022, 2:03 a.m.