getGroupingOptions: Obtain names of variables that group the cells

View source: R/deprecated.R

getGroupingOptionsR Documentation

Obtain names of variables that group the cells

Description

This function returns the names of the variables that group cell ids and can therefore be used as input for the across argument.

Usage

getGroupingOptions(object, phase = NULL)

getAcrossOptions(object, phase = NULL)

Arguments

object

A valid cypro object.

phase

Character or numeric. If character, the ordinal value referring to the phase of interest (e.g. 'first', 'second' etc.). referring to the phase of interest or 'all'. If numeric, the number referring to the phase.

If set to NULL takes the phase denoted as default with adjustDefault().

Ignored if the experiment design contains only one phase.

Value

An informative list.


theMILOlab/cypro documentation built on April 5, 2022, 2:03 a.m.