| check_object | R Documentation |
Makes sure that object input is of class cypro and that it contains the relevant information needed for the function.
check_object( object, experiment = NULL, set_up_req = "process_data", exp_type_req = NULL, module_req = NULL )
object |
A valid cypro object. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.