View source: R/compute-family.R
| compute_migration_efficiency | R Documentation |
Calculate migration efficiency
compute_migration_efficiency(x_coords, y_coords, total_dist)
x_coords |
Numeric vector. Refers to x-coordinates of object. |
y_coords |
Numeric vector. Refers to y-coordinates of object. |
total_dist |
Numeric vector/value. Refers to the total distance the object of interested has traveled. |
A numeric value assessing how efficient the object of interested has migrated.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.