| getGroupingOptions | R Documentation |
This function returns the names of the variables that
group cell ids and can therefore be used as input for the across
argument.
getGroupingOptions(object, phase = NULL) getAcrossOptions(object, phase = NULL)
object |
A valid cypro object. |
phase |
Character or numeric. If character, the ordinal value referring to the phase of interest (e.g. 'first', 'second' etc.). referring to the phase of interest or 'all'. If numeric, the number referring to the phase. If set to NULL takes the phase denoted as default with Ignored if the experiment design contains only one phase. |
An informative list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.